<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Http\Requests\StoreArticleRequest;
use App\Article; 
use App\Categorie; 
use Gate;
use DB; 
use Session; 
use Symfony\Component\HttpFoundation\Response;
use App\User; 

class ArticleController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //
        //dd(User::has('roles.users', '=', 1)->get()); 
        abort_if(Gate::denies('article_liste'), Response::HTTP_FORBIDDEN, 'Accés Refusé !');

        /*$articles = DB::table('articles')
        ->join('categories', 'categories.id', 'articles.categorie_id')
        ->select('categories.categorie', 'articles.*')
        ->get(); 
        */
        //$categories = DB::table('llx_categorie')->get(); 
        $articles = DB::table('llx_product')->get(); 

        return view('admin.articles.index', compact('articles'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
        abort_if(Gate::denies('article_creer'), Response::HTTP_FORBIDDEN, 'Accés Refusé !');

        $categories = DB::table('llx_categorie')->select('rowid', 'label')->get(); 

        return view('admin.articles.create', compact('categories'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
        $this->validate($request, [
            'libelle' => 'required', 
            'prix' => 'required'
        ]); 

        $id = DB::table('llx_product')
        ->insertGetId([
            'ref' => ' ', 
            'label' =>  $request->libelle, 
            'fk_parent' => $request->categorie_id, 
            'price' => $request->prix, 
            'prix_1' => $request->prix_1, 
            'prix_2' => $request->prix_2, 
            'mini_description' => $request->mini_description, 
            'description' => $request->description,
            'stock' => $request->quantite, 
            'tosell' => $request->tosell, 
            'tobuy' => $request->tobuy
        ]); 

        if($request->file('image')){
            $file= $request->file('image');
            $filename= $id.'-'.date('YmdHi').$file->getClientOriginalName();
            $file->move(public_path('image-produit'), $filename);
         

            DB::table('llx_product')->where('rowid', '=', $id)
            ->update([
                'canvas' => $filename 
            ]); 
        }   

        Session::flash('success', 'Produit ajouté avec succé !'); 

        return redirect()->route('admin.articles.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //

        $article = DB::table('llx_product')->select('rowid', 'label', 'canvas', 'price', 'prix_1' , 'prix_2', 'mini_description', 'description', 'stock', 'tosell', 'tobuy')
        ->where('rowid', '=', $id)->first(); 

    
        $categories = DB::table('llx_categorie')->select('rowid', 'label')->get(); 

        return view('admin.articles.show', compact('article', 'categories', 'id')); 
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //

        $article = DB::table('llx_product')->select('rowid', 'label', 'fk_parent', 'price', 'prix_1', 'prix_2',  'mini_description',  'description', 'stock', 'tosell', 'tobuy')
        ->where('rowid', '=', $id)->first(); 
 
        $categories = DB::table('llx_categorie')->select('rowid', 'label')->get(); 

        return view('admin.articles.edit', compact('article', 'categories', 'id')); 
    }

    /**    
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    
    public function update(Request $request, $id)
    {
        // 
  
        $this->validate($request, [
            'libelle' => 'required', 
            'prix' => 'required'
        ]); 

        DB::table('llx_product')->where('rowid', '=', $id)
        ->update([
            'label' =>  $request->libelle, 
            'fk_parent' => $request->categorie_id, 
            'price' => $request->prix, 
            'prix_1' => $request->prix_1, 
            'prix_2' => $request->prix_2, 
            'mini_description' => $request->mini_description, 
            'description' => $request->description,
            'stock' => $request->quantite, 
            'tosell' => $request->tosell, 
            'tobuy' => $request->tobuy
        ]); 

        if($request->file('image')){
            $file= $request->file('image');
            $filename= $id.'-'.date('YmdHi').$file->getClientOriginalName();
            $file->move(public_path('image-produit'), $filename);
         

            DB::table('llx_product')->where('rowid', '=', $id)
            ->update([
                'canvas' => $filename 
            ]); 
        }   

        Session::flash('success', 'Produit modifié avec succé !'); 
        return redirect()->route('admin.articles.index'); 
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //

        dd($id); 
        DB::table('llx_product')->where('rowid', '=' , $id)->delete(); 
        
        Session::flash('success', 'Produit supprimé avec succée !'); 
        return redirect()->back(); 
        
    }
}
