<?php

namespace App\Http\Controllers\Admin;

use App\Client;
use App\ClientStatus;
use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyClientRequest;
use App\Http\Requests\StoreClientRequest;
use App\Http\Requests\UpdateClientRequest;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use DB; 
use Auth; 
use Session; 

class ClientController extends Controller
{
    public function index()
    {
     
        abort_if(Gate::denies('client_liste'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        if(Auth::user()->roles[0]->title == 'Commerciale')
        {
            $clients = DB::table('llx_societe')
            ->join('llx_societe_commerciaux', 'llx_societe_commerciaux.fk_soc', '=', 'llx_societe.rowid')
            ->select('llx_societe.rowid', 'llx_societe.nom',  'llx_societe.phone', 'llx_societe.address', 'llx_societe.datec')->where('llx_societe.client', '=', 1)
            ->where('llx_societe_commerciaux.fk_user', '=', Auth::user()->id)->get(); 
        }
        else {
            $clients = DB::table('llx_societe')
            ->select('rowid', 'nom',  'phone', 'address', 'datec')->where('client', '=', 1)->get(); 
        }

        return view('admin.clients.index', compact('clients'));
    }

    public function create()
    {
        abort_if(Gate::denies('client_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        //$statuses = ClientStatus::all()->pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');
                
        $users = DB::table('users')->select('id', 'name', 'email')->get(); 

        return view('admin.clients.create', compact('users'));
    }
 
    public function store(StoreClientRequest $request)
    {
        $res = DB::table('llx_societe')->where('phone', '=', $request->telephone)->first(); 

        if($res != NULL){
            Session::flash('warning', 'Ce client existe déjà'); 
            return redirect()->back(); 
        }

       $client =  DB::table('llx_societe')->insertGetId([
            'nom' => $request->nom_complet, 
            'phone' => $request->telephone,
            'email' => $request->email,
            'address' => $request->address, 
            'numcompt' => $request->numcompt,
            'gestcompt' => $request->gestcompt,
            'client' => 1,
        ]);

        if($request->commercial != NULL)
        {
            DB::table('llx_societe_commerciaux')->insert([
                'fk_soc' => $client,
                'fk_user' => $request->commercial
            ]); 
        }

        Session::flash('success', 'Client ajouté avec succée !'); 
        return redirect()->route('admin.clients.index');
    }

    public function edit($id)
    {
        dd('Page en Maintenance'); 
        abort_if(Gate::denies('client_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $statuses = ClientStatus::all()->pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $client->load('status');

        return view('admin.clients.edit', compact('statuses', 'client'));
    }

    public function update(UpdateClientRequest $request, Client $client)
    {
        $client->update($request->all());

        return redirect()->route('admin.clients.index');
    }

    public function show(Client $client)
    {


        abort_if(Gate::denies('client_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $client->load('status');

        return view('admin.clients.show', compact('client'));
    }

    public function destroy(Client $client)
    {
        abort_if(Gate::denies('client_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $client->delete();

        return back();
    }

    public function massDestroy(MassDestroyClientRequest $request)
    {
        Client::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
 