<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use DB;
use Session; 
use Auth; 
use App\Http\Controllers\Controller;
use Gate;
use Symfony\Component\HttpFoundation\Response;
use Carbon\Carbon;

class CommandeFournisseurController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Responsee
     */
    public function index()
    {
        //
        abort_if(Gate::denies('commande_fournisseur_liste'), Response::HTTP_FORBIDDEN, 'Accés Interdit !');
 
        $commandes_bd = DB::table('llx_commande_fournisseur')
        ->join('llx_societe', 'llx_societe.rowid', '=', 'llx_commande_fournisseur.fk_soc')
        ->join('users', 'users.id', '=', 'llx_commande_fournisseur.fk_user_author')
        ->select('llx_societe.nom', 'llx_commande_fournisseur.rowid', 'llx_commande_fournisseur.ref', 'llx_commande_fournisseur.date_creation', 'llx_commande_fournisseur.total_ttc', 'llx_commande_fournisseur.fk_statut' , 'users.name', 'llx_societe.canvas')
        ->orderBy('rowid', 'desc')
        ->limit(300)
        ->get(); 

         //dd($commandes_bd[100]); 
        
        $commandes_bd = collect($commandes_bd); 
               
        $commandes = $commandes_bd->each(function($item, $key){
            
            if($item->fk_statut == 0) 
            {
                $item->fk_statut = 'Brouillon';
                $item->canvas = 'none'; 
              
            }
            
            if($item->fk_statut == 1) 
            {
                $item->fk_statut = 'Validé';
                $item->canvas = 'none'; 
              
            }

            if($item->fk_statut == 2) 
            {
                $item->fk_statut = 'Approuvé';
                $item->canvas = 'none'; 
              
            }
            if($item->fk_statut == 3) 
            {
                $item->fk_statut = 'Commandé';
                $item->canvas = 'bg-warning'; 
              
            }

            else if($item->fk_statut == 4)  
            {
                $item->fk_statut = 'Commandé - En cours';
                $item->canvas = 'bg-warning'; 
              
            }
            else if ($item->fk_statut == 5)
            {
                $item->fk_statut = 'Produit Reçu';
                $item->canvas = 'bg-success'; 
            }
            
        });

        return view('admin.commande_fournisseurs.index', compact('commandes'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
        abort_if(Gate::denies('commande_fournisseur_creer'), Response::HTTP_FORBIDDEN, 'Accés Interdit !');

        $fournisseurs = DB::table('llx_societe')
        ->select('rowid', 'nom',  'phone', 'address', 'datec')->where('fournisseur', '=', 1)->get(); 

        return view('admin.commande_fournisseurs.create', compact('fournisseurs'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
        abort_if(Gate::denies('commande_fournisseur_creer'), Response::HTTP_FORBIDDEN, 'Accés Interdit !');

        $this->validate($request, [
            'fournisseur' => 'required', 
            'date' => 'required'
        ]); 

        $date = Carbon::parse($request->date);
   
        $commande_fournisseur_id =  DB::table('llx_commande_fournisseur')->insertGetId([
            'fk_soc' => $request->fournisseur, 
            'ref' => Carbon::now(),
            'date_creation' => Carbon::now(),
            'date_commande' => $date->year. '-'. $date->month. '-'. $date->day,
            'note_public' => $request->note,
            'source' => 0,
            'fk_user_author' => Auth::user()->id,
        ]);

        $ref = 'PO'.$request->date[8].''.$request->date[9]. $request->date[3].''.$request->date[4] .'-'. $commande_fournisseur_id; 

        DB::table('llx_commande_fournisseur')->where('rowid', '=', $commande_fournisseur_id)
        ->update([
            'ref' => $ref
        ]); 
      
/*
        $soc = DB::table('llx_societe')->select('nom')
        ->where('rowid', '=', $request->fournisseur)->first(); 
        */
        /*
            $commercial = DB::table('users')
            ->join('llx_societe_commerciaux', 'llx_societe_commerciaux.fk_user', '=', 'users.id')
            ->select('llx_societe_commerciaux.fk_soc', 'llx_societe_commerciaux.fk_user', 'users.name')
            ->where('llx_societe_commerciaux.fk_soc', '=', $request->client_id)->first(); 

            $client =  DB::table('llx_commande_extrafields')->insert([
                'fk_object' => $commande_id, 
                'tms' =>  $date->year .'-'. $date->month. '-' .$date->day,
                'numcom' => $commercial->name ?? '', 
                'programme' => $request->programme, 
                'banque' => $request->agence, 
                'avis_banque' => $request->avis_banque
            ]);
        */

        Session::flash('success', 'Commande ajouté avec succée ! Maintenant veuillez choisir les produits !'); 
        return redirect()->route('admin.commande_fournisseur.show', $commande_fournisseur_id);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
        abort_if(Gate::denies('commande_fournisseur_voire'), Response::HTTP_FORBIDDEN, 'Accés Interdit !');

        $commande_fournisseur = DB::table('llx_commande_fournisseur')
        ->join('llx_societe', 'llx_societe.rowid', '=', 'llx_commande_fournisseur.fk_soc')
        ->join('users', 'users.id', '=', 'llx_commande_fournisseur.fk_user_author')
        ->select('llx_societe.rowid as fournisseur_id', 'llx_societe.nom', 'users.name', 'llx_commande_fournisseur.rowid', 'llx_commande_fournisseur.ref', 'llx_commande_fournisseur.date_commande', 'llx_commande_fournisseur.total_ttc', 'llx_commande_fournisseur.fk_statut')
        ->where('llx_commande_fournisseur.rowid', '=', $id)
        ->first(); 
    
        $fournisseur = DB::table('llx_societe')
                ->where('llx_societe.rowid', '=', $commande_fournisseur->fournisseur_id)
                ->first(); 

        //$user = DB::table('users')->where('id', '=', $commande_clients->user_id)->first(); 
       
        $commande_articles = DB::table('llx_commande_fournisseurdet')
            ->join('llx_product', 'llx_product.rowid', '=', 'llx_commande_fournisseurdet.fk_product')
            ->select('llx_product.rowid', 'llx_product.label', 'llx_commande_fournisseurdet.subprice', 'llx_commande_fournisseurdet.qty', 'llx_commande_fournisseurdet.description', 'llx_commande_fournisseurdet.total_ttc', 'llx_commande_fournisseurdet.fk_societe')
            ->where('llx_commande_fournisseurdet.fk_commande', '=', $id)
            ->get(); 

        if($commande_articles->count() == 0)
        {
            $commande_articles = DB::table('llx_commande_fournisseurdet')
            ->select('llx_commande_fournisseurdet.rowid', 'llx_commande_fournisseurdet.label', 'llx_commande_fournisseurdet.subprice', 'llx_commande_fournisseurdet.qty', 'llx_commande_fournisseurdet.description', 'llx_commande_fournisseurdet.total_ttc')
            ->where('llx_commande_fournisseurdet.fk_commande', '=', $id)
            ->get(); 
        }
        
        $articles = DB::table('llx_product')
        ->select('rowid', 'label', 'price', 'description')->get(); 

        $clients = DB::table('llx_societe')
        ->select('rowid', 'nom',  'phone')->where('client', '=', 1)->get(); 

        
        return view('admin.commande_fournisseurs.show',
        compact('commande_fournisseur', 'commande_articles', 'articles', 'id', 'fournisseur', 'clients'));
    }
    
    public function ajout_article(Request $request)
    {
        $this->validate($request, [
            'produit' => 'required', 
            'prix' => 'required'
        ]); 

        $article = DB::table('llx_product')
        ->select('label', 'description')
        ->where('rowid', '=', $request->article_id)
        ->first(); 

        $commande_article = DB::table('llx_commandedet')->insert([
            'fk_commande' => $request->commande_id, 
            'fk_product' => $request->article_id, 
            'price' => $request->prix, 
            'description' => $article->description, 
            'qty' => $request->quantite, 
            'remise_percent' => $request->remise, 
            'total_ht' =>  $request->prix * $request->quantite * (1 - $request->reduction / 100), 
        ]);

        Session::flash('success', 'Produit ajouté à la commande avec succée !'); 
        return redirect()->back();
    }   

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
        abort_if(Gate::denies('commande_fournisseur_modifier'), Response::HTTP_FORBIDDEN, 'Accés Interdit !');

        $commande = DB::table('llx_commande')
        ->join('llx_societe', 'llx_societe.rowid', '=', 'llx_commande.fk_soc')
        ->join('llx_commande_extrafields', 'llx_commande_extrafields.fk_object', '=', 'llx_commande.rowid')
        ->select('llx_commande.rowid', 'llx_commande.date_commande', 'llx_commande.note_public', 'llx_societe.rowid as client_id', 'llx_societe.nom', 'llx_societe.phone', 'llx_commande_extrafields.avis_banque', 'llx_commande_extrafields.programme', 'llx_commande.agence')
        ->where('llx_commande.rowid', '=', $id)
        ->first(); 

        $date_parse = Carbon::parse($commande->date_commande); 

        $date = $date_parse->day.'-'. $date_parse->month .'-'. $date_parse->year; 
       

        $clients = DB::table('llx_societe')
        ->select('llx_societe.rowid', 'llx_societe.nom', 'llx_societe.phone')
        ->get(); 

        $agences = DB::table('agences')
        ->join('regions', 'regions.id', '=', 'agences.region_id')
        ->select('agences.id', 'regions.libelle', 'agences.agence')
        ->get(); 
        
        
        return view('admin.commande_client.edit', compact('id', 'date', 'commande', 'clients', 'agences')); 
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
        abort_if(Gate::denies('commande_fournisseur_modifier'), Response::HTTP_FORBIDDEN, 'Accés Interdit !');

        $date = Carbon::parse($request->date);
        //dd($request->avis_banque); 
        //dd($request->date); 
        
        $commande = DB::table('llx_commande')
        ->join('llx_societe_commerciaux', 'llx_societe_commerciaux.fk_soc', '=', 'llx_commande.fk_soc')
        ->select('llx_commande.rowid', 'llx_societe_commerciaux.fk_user')
        ->where('llx_commande.rowid', '=', $id)
        ->first();  
    
        $taux = DB::table('user_commissions')
        ->join('commissions', 'commissions.id', '=', 'user_commissions.commission_id')
        ->select('commissions.montant')
        ->where('user_commissions.user_id', '=', $commande->fk_user)
        ->first();

        $commission = 0; 

        $somme = DB::table('llx_commandedet')
        ->select(DB::raw('SUM(total_ttc) as somme'))
        ->where('fk_commande', '=', $id)
        ->first(); 

        $somme = (int) $somme->somme;

        //$commande_extra = DB::table('llx_commande_extrafields')->select('avis_banque')->where('fk_object', '=', $id)->first(); 

        if($request->avis_banque == 2 && $taux != NULL)
        {
            $commission = ($taux->montant / 100 ) * $somme; 
        }

        DB::table('llx_commande')->where('rowid', '=', $id)
        ->update([
            'fk_soc' => $request->client_id, 
            'date_commande' => $date->year. '-'. $date->month. '-'. $date->day,
            'agence' => $request->agence, 
            'note_public' => $request->note,
            'fk_user_modif' => Auth::user()->id,
            'commission' => $commission, 
            'note_public' => $request->note
        ]); 

        
        DB::table('llx_commande_extrafields')->where('fk_object', '=', $id)
        ->update([
            'fk_object' => $id, 
            'tms' =>  $date->year .'-'. $date->month. '-' .$date->day,
            'programme' => $request->programme, 
            'banque' => $request->agence,
            'avis_banque' => $request->avis_banque
        ]); 

        if($request->avis_banque == 2) {
            $users = User::all(); 
            
            Notification::send($users, new CommandeValideNotification('notification envoyé !')); 
        }
        Session::flash('success', 'Commande modifié avec succée !'); 
        return redirect()->route('admin.commande_client.index'); 
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }

    public function valider(Request $request)
    {   
        
        $commande = DB::table('llx_commande_fournisseur')
        ->join('llx_societe_commerciaux', 'llx_societe_commerciaux.fk_soc', '=', 'llx_commande_fournisseur.fk_soc')
        ->select('llx_commande_fournisseur.rowid', 'llx_societe_commerciaux.fk_user')
        ->where('llx_commande_fournisseur.rowid', '=', $request->id)
        ->first();  

        //dd($commande, $commission, $request->id); 
        
        /*
            $commande = DB::table('llx_commande')
            ->select('fk_soc')
            ->where('rowid', '=', $request->id)
            ->first(); 

            $user = DB::table('llx_societe_commerciaux')
            ->select('rowid', 'fk_user')->where('fk_soc', '=', $commande->fk_soc)
            ->orderBy('rowid', 'DESC')
            ->first(); 
        */

        $somme = DB::table('llx_commande_fournisseurdet')
        ->select(DB::raw('SUM(total_ttc) as somme'))
        ->where('fk_commande', '=', $request->id)
        ->first(); 
      
        $somme = (int) $somme->somme;

        if($somme == 0) {
            Session::flash('warning', 'Veuillez ajouter de produit avant de valider la commande !'); 
            return redirect()->back(); 
        }

        $commande = DB::table('llx_commande_fournisseur')
        ->where('rowid', '=', $request->id)
        ->update([
            'fk_statut' => 4,
            'total_ttc' => $somme, 
            'fk_user_valid' => Auth::user()->id, 
            'fk_user_approve' => Auth::user()->id 
        ]); 
        
       
        Session::flash('success', 'Commande Validé et Approuvé avec succée !'); 
        return redirect()->back(); 
        //  {!! QrCode::size(300)->generate('RemoteStack') !!} 
    }

    public function brouillon(Request $request)
    {
        abort_if(Gate::denies('commande_fournisseur_modifier'), Response::HTTP_FORBIDDEN, 'Accés Interdit !');

        DB::table('llx_commande_fournisseur')
        ->where('rowid', '=', $request->id)
        ->update([
            'fk_statut' => 0,
        ]); 
        
        return redirect()->back(); 
    }

    public function recu(Request $request)
    {
        abort_if(Gate::denies('commande_fournisseur_modifier'), Response::HTTP_FORBIDDEN, 'Accés Interdit !');

        $commande = DB::table('llx_commande_fournisseur')
        ->where('rowid', '=', $request->id)
        ->update([
            'fk_statut' => 5,
        ]); 

        return redirect()->back(); 
    }

    public function facture_create($id)
    {
        
        return view('admin.facture_client.facture_create', compact('id')); 
    }

    public function facture_store(Request $request)
    {
  
        $commande_articles = DB::table('commande_article_clients')
            ->join('articles', 'articles.id', '=', 'commande_article_clients.article_id')
            ->select('articles.libelle', 'commande_article_clients.*')
            ->where('commande_article_clients.commande_id', '=', $request->id)
            ->get(); 

        //dd($commande_articles); 
        $commande = CommandeClient::find($request->id); 

        $facture = new FactureClient; 

        $facture->commande_client_id = $request->id; 
        $facture->client_id = $commande->client_id; 
        $facture->date = $request->date; 
        $facture->montant = $commande->montant; 
        $facture->user_id = Auth::user()->id; 
        $facture->save(); 

        foreach($commande_articles as $c)
        {
            $commande = CommandeArticleClient::find($c->id); 
            $commande->facture_client_id = $facture->id; 
            $commande->save(); 
        }

        return redirect()->route('admin.facture_client.show', $facture->id); 
    }

    public function bordereauLivraisonCreate(Request $request)
    {
  
        $commande = CommandeClient::find($request->id); 

    

        return redirect()->route('admin.commande_client.create', $facture->id); 
    } 

    
    public function rapport(Request $request)
    {
     
/*
        $raps = DB::table('llx_commande')
        ->join('llx_commande_extrafields', 'llx_commande_extrafields.fk_object', '=', 'llx_commande.rowid')
        ->select('llx_commande')->get(); 
*/       
        if($request->annee == NULL) {

            //$mois = (Carbon::now()->month < 10) ? '0'. Carbon::now()->month : Carbon::now()->month; 
            $date = Carbon::now()->year;
        } else {
            
            /*$d = explode('-', $request->mois); 
                $date = $d[1] .'-'. $d[0]; 
                $mois = (Carbon::parse($date)->month < 10) ? '0'. Carbon::parse($date)->month : Carbon::parse($date)->month; 
            */
            dd($request->all());
            $date = Carbon::parse($date)->year; 
        }

      

        $rap_bd = DB::table('llx_commande_fournisseur')
        ->select('llx_commande_fournisseur.date_commande', 'llx_commande_fournisseur.total_ttc')
        ->where('llx_commande_fournisseur.fk_statut', '=', 5)
        ->where('llx_commande_fournisseur.date_commande', 'like', $date.'%')
        ->get(); 
        
        //dd($rap_bd); 
       //dd($rap_bd); 
      /*  $rap_bd = DB::table('llx_commande')
        ->join('llx_commande_extrafields', 'llx_commande_extrafields.fk_object', '=', 'llx_commande.rowid')
        ->select('llx_commande.date_commande', 'llx_commande.fk_user_author', 'llx_commande.total_ttc', 'llx_commande_extrafields.avis_banque')
        ->where('llx_commande_extrafields.avis_banque', '=', 1)
        ->get(); 
*/
        $rap = collect($rap_bd); 
  

        $rap = $rap->each(function($item, $key){
            //dd(explode('-', $item->date_creation)[0]);
            $d = explode('-', $item->date_commande); 
            //dd($d); 
            $mois = $d[1]; 
            $annee = $d[0]; 

            $item->date_commande = $mois .'-'. $annee ; 
        }); 

        $rap = collect($rap)->groupBy('date_commande')->map(function($row){
            //dd($row); 
            return $row->sum('total_ttc'); 
        }); 
        
        $date_commandes = []; 
        $montants = []; 
        foreach($rap as $date_commande => $montant)
        {
            $date_commandes[] = $date_commande; 
            $montants[] = $montant; 
        }

        
        return view('admin.commande_fournisseurs.rapport', compact('rap', 'date', 'date_commandes', 'montants')); 
    }

}
