<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyUserRequest;
use App\Http\Requests\StoreUserRequest;
use App\Http\Requests\UpdateUserRequest;
use App\Role;
use App\User;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use App\UserCommission; 
use App\UserObjectif; 
use App\Commission; 
use App\Objectif; 
use Session;
use DB; 
use Auth;

class UsersController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('user_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

       
        $users = User::all();
       
        return view('admin.users.index', compact('users'));
    }

    public function create()
    {
        abort_if(Gate::denies('user_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $roles = Role::all()->pluck('title', 'id');

        $commissions = Commission::all(); 
        $objectifs = Objectif::all(); 
        //dd($commissions, $objectifs); 
        return view('admin.users.create', compact('roles', 'commissions', 'objectifs'));
    }

    public function store(StoreUserRequest $request)
    {
        //dd($request->commission, $request->objectif); 
        $user = User::create($request->all());
        $user->roles()->sync($request->input('roles', []));
        
        if($request->commission != NULL){
            UserCommission::create([
                'user_id' => $user->id, 
                'commission_id' => $request->commission
            ]);
        }

        if($request->objectif != NULL){
            UserObjectif::create([
                'user_id' => $user->id, 
                'objectif_id' => $request->objectif
            ]);
        }

        Session::flash('success', 'Utilisateur ajouté avec succée'); 
        return redirect()->route('admin.users.index');
    }

    public function edit(User $user)
    {
        abort_if(Gate::denies('user_modifier'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $roles = Role::all()->pluck('title', 'id');

        $user->load('roles');

        $commissions = Commission::all(); 
        $objectifs = Objectif::all(); 

        $user_commission = DB::table('user_commissions')
        ->select('id', 'user_id', 'commission_id')
        ->where('user_id', '=', $user->id)->orderBy('id', 'DESC')->first(); 
        
        $user_objectif = DB::table('user_objectifs')
        ->select('id', 'user_id', 'objectif_id')
        ->where('user_id', '=', $user->id)->orderBy('id', 'DESC')->first(); 

        $user_commission_id = $user_commission->commission_id?? ''; 
        $user_objectif_id = $user_objectif->objectif_id?? ''; 

        return view('admin.users.edit', compact('roles', 'user', 'user_objectif_id', 'user_commission_id', 'commissions', 'objectifs'));
    }

    public function update(UpdateUserRequest $request, User $user)
    {
        if($request->password == NULL) {
            $user->update([
                'name' => $request->name, 
                'email' => $request->email, 
                'roles' => $request->roles, 
            ]); 
        }else {
            $user->update($request->all());
        }
        if($request->commission != NULL && $request->objectif != NULL ) {

            $commission = DB::table('user_commissions')
            ->select('id', 'user_id', 'commission_id')
            ->where('user_id', '=', $user->id)
            ->first(); 

            $objectif = DB::table('user_objectifs')
            ->select('id', 'user_id', 'objectif_id')
            ->where('user_id', '=', $user->id)
            ->first(); 

            if($commission == NULL && $objectif == NULL){
                UserCommission::create([
                    'user_id' => $user->id, 
                    'commission_id' => $request->commission
                ]);

                UserObjectif::create([
                    'user_id' => $user->id, 
                    'objectif_id' => $request->objectif
                ]);
            }else {
                DB::table('user_commissions')->where('id', '=', $commission->id)->update([
                    'user_id' => $user->id, 
                    'commission_id' => $request->commission
                ]); 

                DB::table('user_objectifs')->where('id', '=', $objectif->id)->update([
                    'user_id' => $user->id, 
                    'objectif_id' => $request->objectif
                ]); 
            }
        }

        $user->roles()->sync($request->input('roles', []));

        Session::flash('succcess', 'Utilisateur modifié avec succées !'); 
        return redirect()->route('admin.users.index');
    }

    public function show(User $user)
    {
        abort_if(Gate::denies('user_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $user->load('roles');

        return view('admin.users.show', compact('user'));
    }

    public function destroy(User $user)
    {
        abort_if(Gate::denies('user_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $user->delete();

        return back();
    }

    public function massDestroy(MassDestroyUserRequest $request)
    {
        User::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    } 

    public function commerciaux()
    {
        //DB::table('users')->select('id', 'name', 'email')->get(); 

        $commerciaux = DB::table('role_user')
        ->join('users', 'users.id', '=', 'role_user.user_id')
        ->join('roles', 'roles.id', '=', 'role_user.role_id')
        ->select('users.id', 'users.name', 'users.email')
        ->where('roles.title', '=', 'Commerciale')
        ->get(); 

      /*  foreach($commerciaux as $c) {
      
        }*/
/*
        $commande = DB::table('llx_societe_commerciaux')
        ->join('llx_societe', 'llx_societe.rowid', '=', 'llx_societe_commerciaux.fk_soc')
        ->join('users', 'users.id', '=', 'llx_societe_commerciaux.fk_user')
        ->join('llx_commande', 'llx_commande.fk_soc', '=', 'llx_societe_commerciaux.fk_soc')
        ->select('llx_commande.total_ttc')
        ->groupBy('llx_societe.commerciaux.fk_soc')
        ->get(); 

        $commande = DB::table('llx_commande')
        ->join('llx_societe', 'llx_societe.id', '=', 'llx_commande.fk_soc')
        ->join('')
        ->get(); */

  

        return view('admin.commerciaux.index', compact('commerciaux')); 
    }

    public function notif_lue()
    {
        Auth::user()->unreadNotifications->markAsRead();

        Session::flash('success', 'Notification Marqué comme lue !'); 

        return redirect()->back(); 
    }
}
